package io.renren.modules.app.service;

import com.baomidou.mybatisplus.service.IService;
import io.renren.modules.app.entity.DyxxEntity;
import io.renren.modules.app.entity.FwxxEntity;
import io.renren.modules.app.entity.LpqcEntity;
import io.renren.modules.app.entity.ZhxxEntity;

import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 楼盘清册
 *
 * @author ly
 * @email 1271428398@qq.com
 * @date 2019-03-22 09:53:01
 */
public interface LpqcService extends IService<LpqcEntity> {

	//保存按钮(楼盘清册导入)
	void insertLpqcdr(Map<String,Object> map);

	//查询栋号编码
	String selectDhbm(String xmbm,String dhmc);

	//插入房屋信息
	void insertFwxx(FwxxEntity fwxxEntity);

	// 获取最新的房屋编码
	String querydhbm();

	String selectDhbm2();

	//获取房屋性质编码
	String selectFwxzID(String value,String type);

	//获取单元编码
	String selectDybm(String dhbm,String dymc);

	//插入单元信息
	void insertDyxx(DyxxEntity dyxxEntity);

	//0y 0/的单元楼层数改为1
	void updateLcs();

	Integer selectDhmc(String xmbm,String dhmc);
	
	List<Integer> selectdhbmbyxmdh(ZhxxEntity zhxxEntity);
	
	void updatezhxxlcs(ZhxxEntity zhxxEntity);
	
	ZhxxEntity selectdhbmbymc(ZhxxEntity zhxxEntity);
	
	String selectdhbmfwbm(ZhxxEntity zhxxEntity);
	
	FwxxEntity selectfwxx(String id);
}
